Package: toastui
Title: Interactive Tables, Calendars and Charts for the Web
Version: 0.4.0
Authors@R: c(
  person("Victor", "Perrier", email = "victor.perrier@dreamrs.fr", role = c("aut", "cre", "cph")),
  person("Fanny", "Meyer", role = "aut"),
  person("NHN FE Development Lab", role = "cph", comment = "tui-grid, tui-calendar, tui-chart libraries"))
Description: Create interactive tables, calendars, charts and markdown WYSIWYG editor with 'TOAST UI' <https://ui.toast.com/> libraries to
  integrate in 'shiny' applications or 'rmarkdown' 'HTML' documents.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Depends: R (>= 2.10)
Imports: utils, htmlwidgets, htmltools, magrittr, phosphoricons, rlang,
        shiny (>= 1.1.0), shinyWidgets
Suggests: apexcharter, bslib, knitr, rmarkdown, scales, tinytest
VignetteBuilder: knitr
RoxygenNote: 7.3.2
URL: https://dreamrs.github.io/toastui/
BugReports: https://github.com/dreamRs/toastui/issues
NeedsCompilation: no
Packaged: 2025-04-03 07:29:27 UTC; perri
Author: Victor Perrier [aut, cre, cph],
  Fanny Meyer [aut],
  NHN FE Development Lab [cph] (tui-grid, tui-calendar, tui-chart
    libraries)
Maintainer: Victor Perrier <victor.perrier@dreamrs.fr>
Repository: CRAN
Date/Publication: 2025-04-03 08:10:02 UTC
Built: R 4.3.3; ; 2025-04-04 15:32:32 UTC; unix
